package com.ruoyi.tcZz.service;

import java.util.List;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcWz;

/**
 * 网站Service接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface ITcWzService 
{
    /**
     * 查询网站
     * 
     * @param id 网站主键
     * @return 网站
     */
    public TcWz selectTcWzById(Long id);

    /**
     * 查询网站列表
     * 
     * @param tcWz 网站
     * @return 网站集合
     */
    public List<TcWz> selectTcWzList(TcWz tcWz);

    /**
     * 新增网站
     * 
     * @param tcWz 网站
     * @return 结果
     */
    public int insertTcWz(TcWz tcWz);

    /**
     * 修改网站
     * 
     * @param tcWz 网站
     * @return 结果
     */
    public int updateTcWz(TcWz tcWz);

    /**
     * 批量删除网站
     * 
     * @param ids 需要删除的网站主键集合
     * @return 结果
     */
    public int deleteTcWzByIds(Long[] ids);

    /**
     * 删除网站信息
     * 
     * @param id 网站主键
     * @return 结果
     */
    public int deleteTcWzById(Long id);


    /**
     * 导入网站信息
     *
     * @return 结果
     */
    public String importUser(List<TcWz> tcWzList);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
